@@ -1,4 +1,4 @@
-portfolio_fun <- function(dataset) {
+portfolio_fun <- function(dataset, ...) {
   prices <- dataset$adjusted
   return(rep(1/ncol(prices), ncol(prices)))
 }
\ No newline at end of file
